@@ -1,25 +1,8 @@
-/****************************************************************************
-**
-** Copyright (C) 2009 Tony Murray <murraytony @ gmail.com>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Tony Murray <murraytony@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "tabbedviewwidget.h"
 #include "krdc_debug.h"
@@ -66,7 +49,7 @@ bool TabbedViewWidgetModel::setData(const QModelIndex &index, const QVariant &va
 {
     if (index.isValid() && role == Qt::EditRole) {
         m_tabWidget->setTabText(index.row(), value.toString());
-        emit dataChanged(index, index);
+        Q_EMIT dataChanged(index, index);
         return true;
     }
     return false;
@@ -93,18 +76,18 @@ QVariant TabbedViewWidgetModel::data(const QModelIndex &index, int role) const
 
 void TabbedViewWidgetModel::emitLayoutAboutToBeChanged()
 {
-    emit layoutAboutToBeChanged();
+    Q_EMIT layoutAboutToBeChanged();
 }
 
 void TabbedViewWidgetModel::emitLayoutChanged()
 {
-    emit layoutChanged();
+    Q_EMIT layoutChanged();
 }
 
 void TabbedViewWidgetModel::emitDataChanged(int index)
 {
     QModelIndex modelIndex = createIndex(index, 1);
-    emit dataChanged(modelIndex, modelIndex);
+    Q_EMIT dataChanged(modelIndex, modelIndex);
 }
 
 TabbedViewWidget::TabbedViewWidget(QWidget *parent)
@@ -233,7 +216,7 @@ void TabbedViewWidget::mouseDoubleClickEvent(QMouseEvent * event)
     }
 
     if (isEmptyTabbarSpace(event->pos())) {
-        emit(tabBarDoubleClicked(-1));
+        Q_EMIT tabBarDoubleClicked(-1);
         return;
     }
 
@@ -244,12 +227,12 @@ void TabbedViewWidget::mouseReleaseEvent(QMouseEvent *event)
 {
     if (event->button() == Qt::MidButton) {
         if (isEmptyTabbarSpace(event->pos())) {
-            emit(mouseMiddleClick(-1));
+            Q_EMIT mouseMiddleClick(-1);
             return;
         }
         int pos = tabBar()->tabAt(event->pos());
         if(pos != -1){
-            emit(mouseMiddleClick(pos));
+            Q_EMIT mouseMiddleClick(pos);
             return;
         }
     }
